---
title: "Architecture"
---

This documentation contains the architectural designs that are specific
to Sprout. For design details on Seedcase as a whole, see the
[Design](https://design.seedcase-project.org) documentation.

The core purpose of these architectural documents is to describe to
ourselves and others what Seedcase Sprout is aiming to accomplish and
how it will do that.
